@@ -71,12 +71,12 @@ def config(in_path: str, out_path: str, flags="", print_log=True, warn=False, sa
 	elif in_ext == "pkl":
 		make = "table"
 		origin = "archive"
-		contents = pd.read_pickle(in_path)['AllPagesText']
+		contents = pd.read_pickle(in_path)['AllPagesText'].tolist()
 		fromArchive = True
 	elif in_ext == "xz":
 		make = "table"
 		origin = "archive"
-		contents = pd.read_pickle(in_path,compression="xz")['AllPagesText']
+		contents = pd.read_pickle(in_path,compression="xz")['AllPagesText'].tolist()
 		fromArchive = True
 	elif in_ext == "csv":
 		make = "table"
@@ -151,7 +151,7 @@ def writeArchive(conf):
 
 	exptime = time.time()
 	paths = pd.Series(contents)
-	allpagestext = paths.map(lambda x: getPDFText(x))
+	allpagestext = contents.map(lambda x: getPDFText(x))
 	timestamp = time.time()
 
 	c = pd.DataFrame({
@@ -212,7 +212,7 @@ def writeTables(conf):
 	exptime = time.time()
 
 	if from_archive == True:
-		b['AllPagesText'] = contents.str.slice(0,100)
+		b['AllPagesText'] = contents
 	else:
 		b['AllPagesText'] = pd.Series(contents).map(lambda x: getPDFText(x))
 
@@ -269,7 +269,7 @@ def writeTables(conf):
 		fees = fees.append(feesheet, ignore_index=True) # -> all fees df
 	except ValueError:
 		pass
-		
+
 	if print_log == True:
 		print(fees)
 
@@ -277,8 +277,14 @@ def writeTables(conf):
 	chargetabs = chargetabs.dropna()
 	charges = charges.dropna()
 	chargetabs = chargetabs.tolist()
-	chargetabs = pd.concat(chargetabs,axis=0,ignore_index=True)
-	charges = charges.append(chargetabs,ignore_index=True)
+	try:
+		chargetabs = pd.concat(chargetabs,axis=0,ignore_index=True)
+	except ValueError:
+		pass
+	try:
+		charges = charges.append(chargetabs,ignore_index=True)
+	except ValueError:
+		pass
 
 	if print_log == True:
 		print(charges)
